@@ -35,12 +35,6 @@ class ScorepDummy(base_instrumenter.BaseInstrumenter):
     def rewind_end(self, name, value):
         pass
 
-    def oa_region_begin(self, name, file_name=None, line_number=None):
-        pass
-
-    def oa_region_end(self, name):
-        pass
-
     def user_enable_recording(self):
         pass
 
