@@ -7,6 +7,11 @@ import pytest
 import re
 import subprocess
 import sys
+import numpy
+
+
+def version_tuple(v):
+    return tuple(map(int, (v.split("."))))
 
 
 def call(arguments, expected_returncode=0, env=None):
@@ -200,26 +205,6 @@ def test_user_rewind(scorep_env, instrumenter):
     assert re.search("MEASUREMENT_ON_OFF[ ]*[0-9 ]*[0-9 ]*Mode: ON", std_out)
 
 
-@foreach_instrumenter
-def test_oa_regions(scorep_env, instrumenter):
-    trace_path = get_trace_path(scorep_env)
-
-    std_out, std_err = call_with_scorep(
-        "cases/oa_regions.py",
-        ["--nopython", "--instrumenter-type=" + instrumenter],
-        env=scorep_env,
-    )
-
-    assert std_err == ""
-    assert std_out == "hello world\n"
-
-    std_out, std_err = call(["otf2-print", trace_path])
-
-    assert std_err == ""
-    assert re.search('ENTER[ ]*[0-9 ]*[0-9 ]*Region: "test_region"', std_out)
-    assert re.search('LEAVE[ ]*[0-9 ]*[0-9 ]*Region: "test_region"', std_out)
-
-
 @pytest.mark.parametrize("instrumenter", ALL_INSTRUMENTERS + [None])
 def test_instrumentation(scorep_env, instrumenter):
     trace_path = get_trace_path(scorep_env)
@@ -254,13 +239,42 @@ def test_user_instrumentation(scorep_env, instrumenter):
     )
 
     assert std_err == ""
-    assert std_out == "hello world\nbaz\nbar\n"
+    assert std_out == "hello world\nbar\nhello world2\nbaz\n"
 
     std_out, std_err = call(["otf2-print", trace_path])
 
     assert std_err == ""
     assert re.search('ENTER[ ]*[0-9 ]*[0-9 ]*Region: "__main__:foo"', std_out)
     assert re.search('LEAVE[ ]*[0-9 ]*[0-9 ]*Region: "__main__:foo"', std_out)
+    assert re.search('ENTER[ ]*[0-9 ]*[0-9 ]*Region: "__main__:foo2"', std_out)
+    assert re.search('LEAVE[ ]*[0-9 ]*[0-9 ]*Region: "__main__:foo2"', std_out)
+    assert re.search('ENTER[ ]*[0-9 ]*[0-9 ]*Region: "instrumentation2:bar"', std_out)
+    assert re.search('LEAVE[ ]*[0-9 ]*[0-9 ]*Region: "instrumentation2:bar"', std_out)
+    assert re.search('ENTER[ ]*[0-9 ]*[0-9 ]*Region: "instrumentation2:baz"', std_out)
+    assert re.search('LEAVE[ ]*[0-9 ]*[0-9 ]*Region: "instrumentation2:baz"', std_out)
+
+
+@foreach_instrumenter
+def test_external_user_instrumentation(scorep_env, instrumenter):
+    trace_path = get_trace_path(scorep_env)
+
+    std_out, std_err = call_with_scorep(
+        "cases/instrumentation.py",
+        ["--nocompiler", "--noinstrumenter", "--instrumenter-type=" +
+            instrumenter, "--instrumenter-file=cases/external_instrumentation.py"],
+        env=scorep_env,
+    )
+
+    assert std_err == ""
+    assert std_out == "hello world\nbaz\nbar\n"
+
+    std_out, std_err = call(["otf2-print", trace_path])
+
+    assert std_err == ""
+    assert re.search('ENTER[ ]*[0-9 ]*[0-9 ]*Region: "instrumentation2:bar"', std_out)
+    assert re.search('LEAVE[ ]*[0-9 ]*[0-9 ]*Region: "instrumentation2:bar"', std_out)
+    assert re.search('ENTER[ ]*[0-9 ]*[0-9 ]*Region: "instrumentation2:baz"', std_out)
+    assert re.search('LEAVE[ ]*[0-9 ]*[0-9 ]*Region: "instrumentation2:baz"', std_out)
 
 
 @foreach_instrumenter
@@ -407,6 +421,10 @@ def test_dummy(scorep_env):
 
 
 @pytest.mark.skipif(sys.version_info.major < 3, reason="not tested for python 2")
+@requires_package("numpy")
+@pytest.mark.skipif(version_tuple(numpy.version.version) >= version_tuple("1.22.0"),
+                    reason="There are some changes regarding __array_function__ in 1.22.0,"
+                           "so the test is no longer needed")
 @foreach_instrumenter
 def test_numpy_dot(scorep_env, instrumenter):
     trace_path = get_trace_path(scorep_env)
